Package 'readosense'

Title: Imports Log and Data Files from Eosense Flux Chambers
Description: Imports log and data files from "Eosense" ecosystem gas flux chambers into dataframes that can directly be used with "fluxible" by Gaudard et al (2025) <doi:10.1111/2041-210X.70161>.
Authors: Joseph Gaudard [aut, cre] (ORCID: <https://orcid.org/0000-0002-6989-7624>)
Maintainer: Joseph Gaudard <[email protected]>
License: GPL (>= 3)
Version: 0.0.1
Built: 2026-05-10 08:40:22 UTC
Source: https://github.com/jogaudard/readosense

Help Index


imports data files from Eosense chambers

Description

imports data files from Eosense chambers

Usage

eo_data(path)

Arguments

path

location of the data files

Value

a dataframe with continuous measurement with timestamps

Examples

path <- system.file("extdata/ex_data", package = "readosense")
eo_data(path)

extracts the environmental data from the logs

Description

extracts the environmental data from the logs

Usage

eo_env(logs)

Arguments

logs

as provided by eo_import_logs

Value

a dataframe with the datetime, air temperature (celsius), and pressure (atm) for all chambers

Examples

path <- system.file("extdata/ex_logs", package = "readosense")
eo_import_logs(path) |>
eo_env()

imports log files from Eosense chambers

Description

imports log files from Eosense chambers

Usage

eo_import_logs(
  path,
  closed = c(1:3),
  open = 0,
  fully_closed = 1,
  colnames = c("port", "valvestatus", "chamberstatus", "aux1", "aux2", "aux3", "aux4",
    "aux5", "temperaturev", "pressure"),
  nb_ports = 12
)

Arguments

path

folder in which the log files are located

closed

status numbers indicating chamber is closed

open

status numbers indicating chamber is open

fully_closed

status number indicating the chamber is fully closed

colnames

column names as defined in Eosense documentation

nb_ports

number of ports

Value

a dataframe with all the information from the logs and measurement id

Examples

path <- system.file("extdata/ex_logs", package = "readosense")
eo_import_logs(path)

extracts the measurements metadata from the logs

Description

extracts the measurements metadata from the logs

Usage

eo_logs(logs, time_buffer = 300)

Arguments

logs

as provided by eo_import_logs

time_buffer

around the full closure of the chamber in seconds

Value

a dataframe with the measurement ids, port, and closing and opening time

Examples

path <- system.file("extdata/ex_logs", package = "readosense")
eo_import_logs(path) |>
eo_logs()